@@ -25,6 +25,7 @@ describe 'vswitch::dpdk' do
       before :each do
         params.merge!(:host_core_list  => '')
         params.merge!(:socket_mem      => '')
+        params.merge!(:socket_limit    => '')
         params.merge!(:memory_channels => '' )
         params.merge!(:pmd_core_list => '')
         params.merge!(:enable_hw_offload => false)
@@ -32,7 +33,7 @@ describe 'vswitch::dpdk' do
       end
       it 'configures dpdk options' do
         is_expected.to contain_vs_config('other_config:dpdk-init').with(
-          :value  => 'true', :wait => true,
+          :value  => true, :wait => true,
         )
         is_expected.to contain_vs_config('other_config:pmd-cpu-mask').with(
           :value  => nil, :wait => false,
@@ -40,23 +41,39 @@ describe 'vswitch::dpdk' do
         is_expected.to contain_vs_config('other_config:dpdk-socket-mem').with(
           :value => '', :wait => false,
         )
+        is_expected.to contain_vs_config('other_config:dpdk-socket-limit').with(
+          :value => '', :wait => false,
+        )
         is_expected.to contain_vs_config('other_config:dpdk-lcore-mask').with(
           :value => nil, :wait => false,
         )
         is_expected.to contain_vs_config('other_config:dpdk-extra').with(
           :value => nil, :wait => false,
         )
-        is_expected.to_not contain_vs_config('other_config:hw-offload')
-        is_expected.to_not contain_vs_config('other_config:emc-insert-inv-prob')
-        is_expected.to_not contain_vs_config('other_config:vlan-limit')
-
+        is_expected.to contain_vs_config('other_config:hw-offload').with(
+          :ensure => 'absent', :restart => true, :wait => true,
+        )
+        is_expected.to contain_vs_config('other_config:emc-insert-inv-prob').with(
+          :ensure => 'absent', :wait => false
+        )
+        is_expected.to contain_vs_config('other_config:vlan-limit').with(
+          :value => nil, :wait => true,
+        )
+      end
+      it 'restarts the service when needed' do
+        is_expected.to contain_exec('restart openvswitch').with(
+          :path        => ['/sbin', '/usr/sbin', '/bin', '/usr/bin'],
+          :command     => "systemctl -q restart %s.service" % platform_params[:ovs_service_name],
+          :refreshonly => true
+        )
       end
     end
 
     context 'when passing all params' do
       before :each do
         params.merge!(:host_core_list  => '1,2')
-        params.merge!(:socket_mem      => '1024')
+        params.merge!(:socket_mem      => '1024,1024')
+        params.merge!(:socket_limit    => '2048,2048')
         params.merge!(:memory_channels => 2)
         params.merge!(:pmd_core_list => '22,23,24,25,66,67,68,69')
         params.merge!(:enable_hw_offload => true)
@@ -65,13 +82,16 @@ describe 'vswitch::dpdk' do
       end
       it 'configures dpdk options' do
         is_expected.to contain_vs_config('other_config:dpdk-init').with(
-          :value  => 'true', :wait => true,
+          :value  => true, :wait => true,
         )
         is_expected.to contain_vs_config('other_config:pmd-cpu-mask').with(
           :value  => '3c0000000003c00000', :wait => false,
         )
         is_expected.to contain_vs_config('other_config:dpdk-socket-mem').with(
-          :value => '1024', :wait => false,
+          :value => '1024,1024', :wait => false,
+        )
+        is_expected.to contain_vs_config('other_config:dpdk-socket-limit').with(
+          :value => '2048,2048', :wait => false,
         )
         is_expected.to contain_vs_config('other_config:dpdk-lcore-mask').with(
           :value => '6', :wait => false,
@@ -80,13 +100,31 @@ describe 'vswitch::dpdk' do
           :value => '-n 2', :wait => false,
         )
         is_expected.to contain_vs_config('other_config:hw-offload').with(
-          :value  => 'true', :notify => 'Service[openvswitch]', :wait => true,
+          :value  => true, :restart => true, :wait => true,
         )
         is_expected.to contain_vs_config('other_config:emc-insert-inv-prob').with(
-          :value  => '0', :wait => false,
+          :value  => 0, :wait => false,
         )
         is_expected.to contain_vs_config('other_config:vlan-limit').with(
-          :value  => '2', :wait => true,
+          :value  => 2, :wait => true,
+        )
+      end
+    end
+
+    context 'when passing arrays' do
+      before :each do
+        params.merge!({
+          :socket_mem   => [1024, 1024],
+          :socket_limit => [2048, 2048],
+        })
+      end
+
+      it 'configres dpdk options with comma-separated lists' do
+        is_expected.to contain_vs_config('other_config:dpdk-socket-mem').with(
+          :value => '1024,1024', :wait => false,
+        )
+        is_expected.to contain_vs_config('other_config:dpdk-socket-limit').with(
+          :value => '2048,2048', :wait => false,
         )
       end
     end
